import configparser

class ConfigToDictionary:

  def __init__(self, config):
    self.config = config

  def dict(self):
    # Parse config file
    parser = configparser.ConfigParser()
    parser.read(self.config)

    # Set config values on Dictionary
    dict = {}
    
    for section in parser.sections():
      dict[section] = {}
      for option in parser.options(section):
        dict[section][option] = parser.get(section, option)

    return dict



from setuptools import setup, find_packages

from codecs import open
from os import path

here = path.abspath(path.dirname(__file__))

# Get the description from the readme.md
with open(path.join(here, 'README.md'), encoding='utf-8') as f:
  long_description = f.read()

setup(
  name='cfgtodict',
  version='0.1.1',
  description='A simple class for converting a *.cfg file to a Python Dictionary',
  long_description=long_description,
  url='https://github.com/joelklabo/cfgtodict',
  author='Joel Klabo',
  author_email='joelklabo@gmail.com',
  license='MIT',
  classifiers=[
    'Development Status :: 4 - Beta',
    'Intended Audience :: Developers',
    'License :: OSI Approved :: MIT License',
    'Programming Language :: Python :: 3',
    'Programming Language :: Python :: 3.2',
    'Programming Language :: Python :: 3.3',
    'Programming Language :: Python :: 3.4'
  ],
  keywords='config dictionary utilities',
  py_modules=['cfgtodict']
)
